Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2595)

Unified Diff: device/bluetooth/bluetooth_local_gatt_characteristic.h

Issue 1973343005: Remove service, add device, in BluetoothLocalGattService::Delegate (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/bluetooth_local_gatt_characteristic.h
diff --git a/device/bluetooth/bluetooth_local_gatt_characteristic.h b/device/bluetooth/bluetooth_local_gatt_characteristic.h
index 5511c79a561700c44c2af3e5cd296ec372ce83bb..d573caccc08b26d2da13556667f7271191fcb240 100644
--- a/device/bluetooth/bluetooth_local_gatt_characteristic.h
+++ b/device/bluetooth/bluetooth_local_gatt_characteristic.h
@@ -55,15 +55,18 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothLocalGattCharacteristic
Permissions permissions,
BluetoothLocalGattService* service);
// Notify that the remote central that the value of this characteristic has
// been changed and the new value is |new_value|. |indicate| should be set to
// true if we want to use an indication instead of a notification. An
// indication waits for a response from the remote, making it more reliable
// but notifications may be faster.
virtual NotificationStatus NotifyValueChanged(
+ const BluetoothDevice* device,
const std::vector<uint8_t>& new_value,
bool indicate) = 0;
+ virtual BluetoothLocalGattService* GetService() const = 0;
+
protected:
BluetoothLocalGattCharacteristic();
~BluetoothLocalGattCharacteristic() override;
@@ -55,15 +55,18 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothLocalGattCharacteristic
Permissions permissions,
BluetoothLocalGattService* service);
- // Notify that the remote central that the value of this characteristic has
- // been changed and the new value is |new_value|. |indicate| should be set to
- // true if we want to use an indication instead of a notification. An
- // indication waits for a response from the remote, making it more reliable
- // but notifications may be faster.
+ // Notify the remote device |device| that the value of characteristic
+ // |characteristic| has changed and the new value is |new_value|. |indicate|
+ // should be set to true if we want to use an indication instead of a
+ // notification. An indication waits for a response from the remote, making
+ // it more reliable but notifications may be faster.
virtual NotificationStatus NotifyValueChanged(

Powered by Google App Engine
This is Rietveld 408576698